@@ -13,6 +13,7 @@ typedef Eo Ecore_Audio_In_Sndfile;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Ecore Audio sndfile input.
  *
  * @ingroup Ecore_Audio_In_Sndfile
@@ -20,5 +21,6 @@ typedef Eo Ecore_Audio_In_Sndfile;
 #define ECORE_AUDIO_IN_SNDFILE_CLASS ecore_audio_in_sndfile_class_get()
 
 EWAPI const Efl_Class *ecore_audio_in_sndfile_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
