@@ -13,6 +13,7 @@ typedef Eo Efl_Net_Dialer_Tcp;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Connects to a remote TCP server.
  *
@@ -32,12 +33,11 @@ typedef Eo Efl_Net_Dialer_Tcp;
  * socks4a://proxyserver:port (SOCKSv4 and let socks server to resolve domain)
  * - socks4://proxyserver:port (SOCKSv4)
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Tcp
  */
 #define EFL_NET_DIALER_TCP_CLASS efl_net_dialer_tcp_class_get()
 
 EWAPI const Efl_Class *efl_net_dialer_tcp_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
