@@ -7,23 +7,15 @@
 #  undef EAPI
 # endif
 
-# ifdef _MSC_VER
-#  ifdef BUILDING_DLL
-#   define EAPI __declspec(dllexport)
-#  else // ifdef BUILDING_DLL
-#   define EAPI __declspec(dllimport)
-#  endif // ifdef BUILDING_DLL
-# else // ifdef _MSC_VER
-#  ifdef __GNUC__
-#   if __GNUC__ >= 4
-#    define EAPI __attribute__ ((visibility("default")))
-#   else // if __GNUC__ >= 4
-#    define EAPI
-#   endif // if __GNUC__ >= 4
-#  else // ifdef __GNUC__
+# ifdef __GNUC__
+#  if __GNUC__ >= 4
+#   define EAPI __attribute__ ((visibility("default")))
+#  else // if __GNUC__ >= 4
 #   define EAPI
-#  endif // ifdef __GNUC__
-# endif // ifdef _MSC_VER
+#  endif // if __GNUC__ >= 4
+# else // ifdef __GNUC__
+#  define EAPI
+# endif // ifdef __GNUC__
 
 # ifdef EFL_BETA_API_SUPPORT
 
@@ -47,6 +39,17 @@ typedef enum _Ecore_Drm2_Fb_Status
    ECORE_DRM2_FB_STATUS_PLANE_RELEASE = 32,
 } Ecore_Drm2_Fb_Status;
 
+typedef enum _Ecore_Drm2_Relative_Mode
+{
+   ECORE_DRM2_RELATIVE_MODE_UNKNOWN,
+   ECORE_DRM2_RELATIVE_MODE_NONE,
+   ECORE_DRM2_RELATIVE_MODE_CLONE,
+   ECORE_DRM2_RELATIVE_MODE_TO_LEFT,
+   ECORE_DRM2_RELATIVE_MODE_TO_RIGHT,
+   ECORE_DRM2_RELATIVE_MODE_TO_ABOVE,
+   ECORE_DRM2_RELATIVE_MODE_TO_BELOW
+} Ecore_Drm2_Relative_Mode;
+
 /* opaque structure to represent a drm device */
 typedef struct _Ecore_Drm2_Device Ecore_Drm2_Device;
 
@@ -144,7 +147,7 @@ EAPI int ecore_drm2_shutdown(void);
 /**
  * Read and process pending Drm events
  *
- * @param fd drm file descriptor
+ * @param dev drm device
  * @param ctx
  *
  * @return 0 on success, -1 otherwise
@@ -156,7 +159,7 @@ EAPI int ecore_drm2_shutdown(void);
  * @ingroup Ecore_Drm_Init_Group
  * @since 1.19
  */
-EAPI int ecore_drm2_event_handle(int fd, Ecore_Drm2_Context *drmctx);
+EAPI int ecore_drm2_event_handle(Ecore_Drm2_Device *dev, Ecore_Drm2_Context *drmctx);
 
 /**
  * @defgroup Ecore_Drm2_Device_Group Drm device functions
@@ -166,30 +169,17 @@ EAPI int ecore_drm2_event_handle(int fd, Ecore_Drm2_Context *drmctx);
  */
 
 /**
- * Try to find a drm device on a given seat
+ * Try to open the Ecore_Drm2_Device for a given seat
  *
  * @param seat
  * @param tty
- * @param sync
  *
- * @return A newly allocated Ecore_Drm2_Device on success, NULL otherwise
+ * @return An Ecore_Drm2_Device or NULL on failure.
  *
  * @ingroup Ecore_Drm2_Device_Group
  * @since 1.18
  */
-EAPI Ecore_Drm2_Device *ecore_drm2_device_find(const char *seat, unsigned int tty);
-
-/**
- * Try to open a given Ecore_Drm2_Device
- *
- * @param device
- *
- * @return A valid file descriptor if open succeeds, -1 otherwise.
- *
- * @ingroup Ecore_Drm2_Device_Group
- * @since 1.18
- */
-EAPI int ecore_drm2_device_open(Ecore_Drm2_Device *device);
+EAPI Ecore_Drm2_Device *ecore_drm2_device_open(const char *seat, unsigned int tty);
 
 /**
  * Close an open Ecore_Drm2_Device
@@ -201,16 +191,6 @@ EAPI int ecore_drm2_device_open(Ecore_Drm2_Device *device);
  */
 EAPI void ecore_drm2_device_close(Ecore_Drm2_Device *device);
 
-/**
- * Free a given Ecore_Drm2_Device
- *
- * @param device
- *
- * @ingroup Ecore_Drm2_Device_Group
- * @since 1.18
- */
-EAPI void ecore_drm2_device_free(Ecore_Drm2_Device *device);
-
 /**
  * Get the type of clock used by a given Ecore_Drm2_Device
  *
@@ -295,6 +275,28 @@ EAPI void ecore_drm2_device_window_set(Ecore_Drm2_Device *device, unsigned int w
  */
 EAPI void ecore_drm2_device_pointer_max_set(Ecore_Drm2_Device *device, int w, int h);
 
+/**
+ * Set pointer acceleration speed
+ *
+ * @param device
+ * @param speed
+ *
+ * @ingroup Ecore_Drm2_Device_Group
+ * @since 1.21
+ */
+EAPI void ecore_drm2_device_pointer_accel_speed_set(Ecore_Drm2_Device *device, double speed);
+
+/**
+ * Set pointer acceleration profile
+ *
+ * @param device
+ * @param profile
+ *
+ * @ingroup Ecore_Drm2_Device_Group
+ * @since 1.21
+ */
+EAPI void ecore_drm2_device_pointer_accel_profile_set(Ecore_Drm2_Device *device, uint32_t profile);
+
 /**
  * Set pointer value rotation
  *
@@ -308,6 +310,17 @@ EAPI void ecore_drm2_device_pointer_max_set(Ecore_Drm2_Device *device, int w, in
  */
 EAPI Eina_Bool ecore_drm2_device_pointer_rotation_set(Ecore_Drm2_Device *device, int rotation);
 
+/**
+ * Enable or disable pointer tap-to-click
+ *
+ * @param device
+ * @param enabled
+ *
+ * @ingroup Ecore_Drm2_Device_Group
+ * @since 1.22
+ */
+EAPI void ecore_drm2_device_touch_tap_to_click_enabled_set(Ecore_Drm2_Device *device, Eina_Bool enabled);
+
 /**
  * Set info to be used on keyboards
  *
@@ -498,20 +511,6 @@ EAPI Eina_Bool ecore_drm2_output_backlight_get(Ecore_Drm2_Output *output);
  */
 EAPI Ecore_Drm2_Output *ecore_drm2_output_find(Ecore_Drm2_Device *device, int x, int y);
 
-/**
- * Get the geometry of a given output
- *
- * @param output
- * @param x
- * @param y
- * @param w
- * @param h
- *
- * @ingroup Ecore_Drm2_Output_Group
- * @since 1.18
- */
-EAPI void ecore_drm2_output_geometry_get(Ecore_Drm2_Output *output, int *x, int *y, int *w, int *h);
-
 /**
  * Get the dpi of a given output
  *
@@ -552,18 +551,6 @@ EAPI unsigned int ecore_drm2_output_crtc_get(Ecore_Drm2_Output *output);
  */
 EAPI Ecore_Drm2_Fb *ecore_drm2_output_latest_fb_get(Ecore_Drm2_Output *output);
 
-/**
- * Get the size of the crtc for a given output
- *
- * @param output
- * @param *w
- * @param *h
- *
- * @ingroup Ecore_Drm2_Output_Group
- * @since 1.18
- */
-EAPI void ecore_drm2_output_crtc_size_get(Ecore_Drm2_Output *output, int *w, int *h);
-
 /**
  * Get if a given output is marked as the primary output
  *
@@ -728,17 +715,19 @@ EAPI Eina_Bool ecore_drm2_output_cloned_get(Ecore_Drm2_Output *output);
 EAPI unsigned int ecore_drm2_output_connector_type_get(Ecore_Drm2_Output *output);
 
 /**
- * Get the current resolution of a given output
+ * Get the geometry and refresh rate for a given output
  *
  * @param output
+ * @param *x
+ * @param *y
  * @param *w
  * @param *h
  * @param *refresh
  *
  * @ingroup Ecore_Drm2_Output_Group
- * @since 1.18
+ * @since 1.21
  */
-EAPI void ecore_drm2_output_resolution_get(Ecore_Drm2_Output *output, int *w, int *h, unsigned int *refresh);
+EAPI void ecore_drm2_output_info_get(Ecore_Drm2_Output *output, int *x, int *y, int *w, int *h, unsigned int *refresh);
 
 /**
  * Get if an output can be used on a given crtc
@@ -803,6 +792,18 @@ EAPI int ecore_drm2_output_supported_rotations_get(Ecore_Drm2_Output *output);
  */
 EAPI Eina_Bool ecore_drm2_output_rotation_set(Ecore_Drm2_Output *output, int rotation);
 
+/**
+ * Get current output rotation
+ *
+ * @param output
+ *
+ * @return An integer representing the output current rotation
+ *
+ * @ingroup Ecore_Drm2_Output_Group
+ * @since 1.22
+ */
+EAPI int ecore_drm2_output_rotation_get(Ecore_Drm2_Output *output);
+
 /**
  * Set the user data for the output's page flip handler
  *
@@ -814,6 +815,18 @@ EAPI Eina_Bool ecore_drm2_output_rotation_set(Ecore_Drm2_Output *output, int rot
  */
 EAPI void ecore_drm2_output_user_data_set(Ecore_Drm2_Output *o, void *data);
 
+/**
+ * Get the user data for a given output
+ *
+ * @param output The output to get user data for
+ *
+ * @return The user data associated with given output
+ *
+ * @ingroup Ecore_Drm2_Output_Group
+ * @since 1.21
+ */
+EAPI void *ecore_drm2_output_user_data_get(Ecore_Drm2_Output *output);
+
 /**
  * Get the subpixel state of the output
  * @param output the output
@@ -823,6 +836,52 @@ EAPI void ecore_drm2_output_user_data_set(Ecore_Drm2_Output *o, void *data);
  */
 EAPI unsigned int ecore_drm2_output_subpixel_get(const Ecore_Drm2_Output *output);
 
+/**
+ * Set the relative mode for an output
+ *
+ * @param output The output to set relative mode
+ * @param relative The relative mode to set
+ *
+ * @ingroup Ecore_Drm2_Output_Group
+ * @since 1.21
+ */
+EAPI void ecore_drm2_output_relative_mode_set(Ecore_Drm2_Output *output, Ecore_Drm2_Relative_Mode mode);
+
+/**
+ * Get the relative mode of an output
+ *
+ * @param output The output to retrieve relative mode for
+ *
+ * @return The relative mode of a given output
+ *
+ * @ingroup Ecore_Drm2_Output_Group
+ * @since 1.21
+ */
+EAPI Ecore_Drm2_Relative_Mode ecore_drm2_output_relative_mode_get(Ecore_Drm2_Output *output);
+
+/**
+ * Set which output a given output is relative to
+ *
+ * @param output The output for which to set relative
+ * @param relative The output for which the first output is relative to
+ *
+ * @ingroup Ecore_Drm2_Output_Group
+ * @since 1.21
+ */
+EAPI void ecore_drm2_output_relative_to_set(Ecore_Drm2_Output *output, const char *relative);
+
+/**
+ * Get which output is relative to a given output
+ *
+ * @param output The output for which to retrieve relative
+ *
+ * @return The name of the output which is relative to the given output or NULL
+ *
+ * @ingroup Ecore_Drm2_Output_Group
+ * @since 1.21
+ */
+EAPI const char *ecore_drm2_output_relative_to_get(Ecore_Drm2_Output *output);
+
 /**
  * @defgroup Ecore_Drm2_Fb_Group Drm framebuffer functions
  *
@@ -832,7 +891,7 @@ EAPI unsigned int ecore_drm2_output_subpixel_get(const Ecore_Drm2_Output *output
 /**
  * Create a new framebuffer object
  *
- * @param fd
+ * @param dev
  * @param width
  * @param height
  * @param depth
@@ -844,9 +903,9 @@ EAPI unsigned int ecore_drm2_output_subpixel_get(const Ecore_Drm2_Output *output
  * @ingroup Ecore_Drm2_Fb_Group
  * @since 1.18
  */
-EAPI Ecore_Drm2_Fb *ecore_drm2_fb_create(int fd, int width, int height, int depth, int bpp, unsigned int format);
+EAPI Ecore_Drm2_Fb *ecore_drm2_fb_create(Ecore_Drm2_Device *dev, int width, int height, int depth, int bpp, unsigned int format);
 
-EAPI Ecore_Drm2_Fb *ecore_drm2_fb_gbm_create(int fd, int width, int height, int depth, int bpp, unsigned int format, unsigned int handle, unsigned int stride, void *bo);
+EAPI Ecore_Drm2_Fb *ecore_drm2_fb_gbm_create(Ecore_Drm2_Device *dev, int width, int height, int depth, int bpp, unsigned int format, unsigned int handle, unsigned int stride, void *bo);
 
 /**
  * Get a framebuffer's mmap'd data
@@ -971,7 +1030,7 @@ EAPI void *ecore_drm2_fb_bo_get(Ecore_Drm2_Fb *fb);
 /**
  * Import a dmabuf object as a Framebuffer
  *
- * @param fd
+ * @param dev
  * @param width
  * @param height
  * @param depth
@@ -987,7 +1046,7 @@ EAPI void *ecore_drm2_fb_bo_get(Ecore_Drm2_Fb *fb);
  * @since 1.20
  *
  */
-EAPI Ecore_Drm2_Fb *ecore_drm2_fb_dmabuf_import(int fd, int width, int height, int depth, int bpp, unsigned int format, unsigned int strides[4], int dmabuf_fd[4], int dmabuf_fd_count);
+EAPI Ecore_Drm2_Fb *ecore_drm2_fb_dmabuf_import(Ecore_Drm2_Device *dev, int width, int height, int depth, int bpp, unsigned int format, unsigned int strides[4], int dmabuf_fd[4], int dmabuf_fd_count);
 
 /**
  * Discard a framebuffer object
@@ -1071,7 +1130,7 @@ EAPI Eina_Bool ecore_drm2_plane_fb_set(Ecore_Drm2_Plane *plane, Ecore_Drm2_Fb *f
  * @param fb The fb to register the callback on
  * @param handler The function to handle the callback
  * @param data The user data to pass to the callback
- * @ingroup Ecore_Drm2_Output_Group
+ * @ingroup Ecore_Drm2_Fb_Group
  * @since 1.20
  */
 EAPI void ecore_drm2_fb_status_handler_set(Ecore_Drm2_Fb *fb, Ecore_Drm2_Fb_Status_Handler handler, void *data);
@@ -1090,10 +1149,36 @@ EAPI void ecore_drm2_fb_status_handler_set(Ecore_Drm2_Fb *fb, Ecore_Drm2_Fb_Stat
  * @param sec
  * @param usec
  *
+ * @ingroup Ecore_Drm2_Output_Group
  * @since 1.20
  */
 EAPI Eina_Bool ecore_drm2_output_blanktime_get(Ecore_Drm2_Output *output, int sequence, long *sec, long *usec);
 
+/**
+ * Get the fd of an Ecore_Drm2_Device
+ *
+ * Query the fd of the device.
+ *
+ * @param device
+ *
+ * @ingroup Ecore_Drm2_Device_Group
+ * @since 1.20
+ */
+EAPI int ecore_drm2_device_fd_get(Ecore_Drm2_Device *device);
+
+/**
+ * Check if there's a pageflip in progress for an output
+ *
+ * Checks whether an output has submit a flip but not yet had
+ * a callback completion event for that flip yet.
+ *
+ * @param output
+ * @return Whether there's a flip in progress or not
+ * @ingroup Ecore_Drm2_Output_Group
+ * @since 1.20
+ */
+EAPI Eina_Bool ecore_drm2_output_pending_get(Ecore_Drm2_Output *output);
+
 # endif
 
 #endif
