@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_List_Default_Item_Part_Icon;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** List Default Item internal content of icon part class
  *
  * @ingroup Efl_Ui_List_Default_Item_Part_Icon
@@ -20,5 +21,6 @@ typedef Eo Efl_Ui_List_Default_Item_Part_Icon;
 #define EFL_UI_LIST_DEFAULT_ITEM_PART_ICON_CLASS efl_ui_list_default_item_part_icon_class_get()
 
 EWAPI const Efl_Class *efl_ui_list_default_item_part_icon_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
