@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Navigation_Bar_Part_Back_Button;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl Ui Navigation_Bar internal part back button class
  *
  * @ingroup Efl_Ui_Navigation_Bar_Part_Back_Button
@@ -20,5 +21,6 @@ typedef Eo Efl_Ui_Navigation_Bar_Part_Back_Button;
 #define EFL_UI_NAVIGATION_BAR_PART_BACK_BUTTON_CLASS efl_ui_navigation_bar_part_back_button_class_get()
 
 EWAPI const Efl_Class *efl_ui_navigation_bar_part_back_button_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
