@@ -11,12 +11,15 @@ typedef Eo Efl_Ui_Tab_Page;
 #ifndef _EFL_UI_TAB_PAGE_EO_TYPES
 #define _EFL_UI_TAB_PAGE_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 typedef enum
 {
   EFL_UI_TAB_PAGE_TAB_CHANGED_LABEL = 0, /**< Label changed */
   EFL_UI_TAB_PAGE_TAB_CHANGED_ICON /**< Icon changed */
 } Efl_Ui_Tab_Page_Tab_Changed;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Information of changed event
  *
  * @ingroup Efl_Ui
@@ -25,6 +28,7 @@ typedef struct _Efl_Ui_Tab_Page_Tab_Changed_Event
 {
   Efl_Ui_Tab_Page_Tab_Changed changed_info;
 } Efl_Ui_Tab_Page_Tab_Changed_Event;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
