@@ -11,57 +11,9 @@ typedef Eo Efl_Ui_Text;
 #ifndef _EFL_UI_TEXT_EO_TYPES
 #define _EFL_UI_TEXT_EO_TYPES
 
-/** EFL UI text anchor information
- *
- * @ingroup Efl_Ui_Text
- */
-typedef struct _Efl_Ui_Text_Anchor_Info
-{
-  const char *name; /**< The name of the anchor, as stated in its href. */
-  int button; /**< The mouse button used to click on it. */
-  int x; /**< Anchor geometry, relative to canvas. */
-  int y; /**< Anchor geometry, relative to canvas. */
-  int w; /**< Anchor geometry, relative to canvas. */
-  int h; /**< Anchor geometry, relative to canvas. */
-} Efl_Ui_Text_Anchor_Info;
-
-/** EFL text hover parent
- *
- * @ingroup Efl_Ui_Text
- */
-typedef struct _Efl_Ui_Text_Hover_Parent
-{
-  int x; /**< Hover parent X coordinate */
-  int y; /**< Hover parent Y coordinate */
-  int w; /**< Hover parent width */
-  int h; /**< Hover parent height */
-} Efl_Ui_Text_Hover_Parent;
-
-/** EFL text anchor hover information
- *
- * @ingroup Efl_Ui_Text
- */
-typedef struct _Efl_Ui_Text_Anchor_Hover_Info
-{
-  const Efl_Ui_Text_Anchor_Info *anchor_info; /**< The actual anchor info. */
-  Elm_Hover *hover; /**< The hover object to use for the popup. */
-  Efl_Ui_Text_Hover_Parent hover_parent; /**< Hover parent widget */
-  Eina_Bool hover_left; /**< Hint indicating if there's space for content on the
-                         * left side of the hover. Before calling the callback,
-                         * the widget will make the necessary calculations to
-                         * check which sides are fit to be set with content,
-                         * based on the position the hover is activated and its
-                         * distance to the edges of its parent object */
-  Eina_Bool hover_right; /**< Hint indicating content fits on the right side of
-                          * the hover. See @.hover_left. */
-  Eina_Bool hover_top; /**< Hint indicating content fits on top of the hover.
-                        * @.hover_left. */
-  Eina_Bool hover_bottom; /**< Hint indicating content fits below the hover. See
-                           * @.hover_left. */
-} Efl_Ui_Text_Anchor_Hover_Info;
-
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl UI text class
  *
  * @ingroup Efl_Ui_Text
@@ -75,6 +27,7 @@ EWAPI const Efl_Class *efl_ui_text_class_get(void);
  *
  * Normally the entry is not scrollable unless you enable it with this call.
  *
+ * @param[in] obj The object.
  * @param[in] scroll @c true if it is to be scrollable, @c false otherwise.
  *
  * @ingroup Efl_Ui_Text
@@ -87,6 +40,8 @@ EOAPI void efl_ui_text_scrollable_set(Eo *obj, Eina_Bool scroll);
  * Normally the entry is not scrollable. This gets the scrollable state of the
  * entry.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if it is to be scrollable, @c false otherwise.
  *
  * @ingroup Efl_Ui_Text
@@ -94,15 +49,14 @@ EOAPI void efl_ui_text_scrollable_set(Eo *obj, Eina_Bool scroll);
 EOAPI Eina_Bool efl_ui_text_scrollable_get(const Eo *obj);
 
 /**
- * @brief Set the attribute to show the input panel in case of only an user's
+ * @brief Set the attribute to show the input panel in case of only a user's
  * explicit Mouse Up event. It doesn't request to show the input panel even
  * though it has focus.
  *
+ * @param[in] obj The object.
  * @param[in] ondemand If @c true, the input panel will be shown in case of
  * only Mouse up event. (Focus event will be ignored.)
  *
- * @since 1.9
- *
  * @ingroup Efl_Ui_Text
  */
 EOAPI void efl_ui_text_input_panel_show_on_demand_set(Eo *obj, Eina_Bool ondemand);
@@ -111,11 +65,11 @@ EOAPI void efl_ui_text_input_panel_show_on_demand_set(Eo *obj, Eina_Bool ondeman
  * @brief Get the attribute to show the input panel in case of only an user's
  * explicit Mouse Up event.
  *
+ * @param[in] obj The object.
+ *
  * @return If @c true, the input panel will be shown in case of only Mouse up
  * event. (Focus event will be ignored.)
  *
- * @since 1.9
- *
  * @ingroup Efl_Ui_Text
  */
 EOAPI Eina_Bool efl_ui_text_input_panel_show_on_demand_get(const Eo *obj);
@@ -123,6 +77,7 @@ EOAPI Eina_Bool efl_ui_text_input_panel_show_on_demand_get(const Eo *obj);
 /**
  * @brief This disables the entry's contextual (longpress) menu.
  *
+ * @param[in] obj The object.
  * @param[in] disabled If @c true, the menu is disabled.
  *
  * @ingroup Efl_Ui_Text
@@ -133,6 +88,8 @@ EOAPI void efl_ui_text_context_menu_disabled_set(Eo *obj, Eina_Bool disabled);
  * @brief This returns whether the entry's contextual (longpress) menu is
  * disabled.
  *
+ * @param[in] obj The object.
+ *
  * @return If @c true, the menu is disabled.
  *
  * @ingroup Efl_Ui_Text
@@ -143,18 +100,18 @@ EOAPI Eina_Bool efl_ui_text_context_menu_disabled_get(const Eo *obj);
  * @brief Control pasting of text and images for the widget.
  *
  * Normally the entry allows both text and images to be pasted. By setting
- * cnp_mode to be #ELM_CNP_MODE_NO_IMAGE, this prevents images from being copy
- * or past. By setting cnp_mode to be #ELM_CNP_MODE_PLAINTEXT, this remove all
+ * cnp_mode to be #ELM_CNP_MODE_NO_IMAGE this prevents images from being copied
+ * or pasted. By setting cnp_mode to be #ELM_CNP_MODE_PLAINTEXT this remove all
  * tags in text .
  *
  * @note This only changes the behaviour of text.
  *
- * @param[in] cnp_mode One of #Elm_Cnp_Mode: #ELM_CNP_MODE_MARKUP,
- * #ELM_CNP_MODE_NO_IMAGE, #ELM_CNP_MODE_PLAINTEXT.
+ * @param[in] obj The object.
+ * @param[in] format Format for copy & paste.
  *
  * @ingroup Efl_Ui_Text
  */
-EOAPI void efl_ui_text_cnp_mode_set(Eo *obj, Elm_Cnp_Mode cnp_mode);
+EOAPI void efl_ui_text_cnp_mode_set(Eo *obj, Efl_Ui_Selection_Format format);
 
 /**
  * @brief Getting elm_entry text paste/drop mode.
@@ -162,18 +119,20 @@ EOAPI void efl_ui_text_cnp_mode_set(Eo *obj, Elm_Cnp_Mode cnp_mode);
  * Normally the entry allows both text and images to be pasted. This gets the
  * copy & paste mode of the entry.
  *
- * @return One of #Elm_Cnp_Mode: #ELM_CNP_MODE_MARKUP, #ELM_CNP_MODE_NO_IMAGE,
- * #ELM_CNP_MODE_PLAINTEXT.
+ * @param[in] obj The object.
+ *
+ * @return Format for copy & paste.
  *
  * @ingroup Efl_Ui_Text
  */
-EOAPI Elm_Cnp_Mode efl_ui_text_cnp_mode_get(const Eo *obj);
+EOAPI Efl_Ui_Selection_Format efl_ui_text_cnp_mode_get(const Eo *obj);
 
 /**
  * @brief Set the language mode of the input panel.
  *
  * This API can be used if you want to show the alphabet keyboard mode.
  *
+ * @param[in] obj The object.
  * @param[in] lang Language to be set to the input panel.
  *
  * @ingroup Efl_Ui_Text
@@ -183,6 +142,8 @@ EOAPI void efl_ui_text_input_panel_language_set(Eo *obj, Elm_Input_Panel_Lang la
 /**
  * @brief Get the language mode of the input panel.
  *
+ * @param[in] obj The object.
+ *
  * @return Language to be set to the input panel.
  *
  * @ingroup Efl_Ui_Text
@@ -190,8 +151,9 @@ EOAPI void efl_ui_text_input_panel_language_set(Eo *obj, Elm_Input_Panel_Lang la
 EOAPI Elm_Input_Panel_Lang efl_ui_text_input_panel_language_get(const Eo *obj);
 
 /**
- * @brief This disabled the entry's selection handlers.
+ * @brief This disables the entry's selection handlers.
  *
+ * @param[in] obj The object.
  * @param[in] disabled If @c true, the selection handlers are disabled.
  *
  * @ingroup Efl_Ui_Text
@@ -201,6 +163,8 @@ EOAPI void efl_ui_text_selection_handler_disabled_set(Eo *obj, Eina_Bool disable
 /**
  * @brief This returns whether the entry's selection handlers are disabled.
  *
+ * @param[in] obj The object.
+ *
  * @return If @c true, the selection handlers are disabled.
  *
  * @ingroup Efl_Ui_Text
@@ -210,10 +174,9 @@ EOAPI Eina_Bool efl_ui_text_selection_handler_disabled_get(const Eo *obj);
 /**
  * @brief Set the input panel layout variation of the entry
  *
+ * @param[in] obj The object.
  * @param[in] variation Layout variation type.
  *
- * @since 1.8
- *
  * @ingroup Efl_Ui_Text
  */
 EOAPI void efl_ui_text_input_panel_layout_variation_set(Eo *obj, int variation);
@@ -221,9 +184,9 @@ EOAPI void efl_ui_text_input_panel_layout_variation_set(Eo *obj, int variation);
 /**
  * @brief Get the input panel layout variation of the entry
  *
- * @return Layout variation type.
+ * @param[in] obj The object.
  *
- * @since 1.8
+ * @return Layout variation type.
  *
  * @ingroup Efl_Ui_Text
  */
@@ -232,6 +195,7 @@ EOAPI int efl_ui_text_input_panel_layout_variation_get(const Eo *obj);
 /**
  * @brief Set the autocapitalization type on the immodule.
  *
+ * @param[in] obj The object.
  * @param[in] autocapital_type The type of autocapitalization.
  *
  * @ingroup Efl_Ui_Text
@@ -241,6 +205,8 @@ EOAPI void efl_ui_text_autocapital_type_set(Eo *obj, Elm_Autocapital_Type autoca
 /**
  * @brief Get the autocapitalization type on the immodule.
  *
+ * @param[in] obj The object.
+ *
  * @return The type of autocapitalization.
  *
  * @ingroup Efl_Ui_Text
@@ -250,27 +216,31 @@ EOAPI Elm_Autocapital_Type efl_ui_text_autocapital_type_get(const Eo *obj);
 /**
  * @brief Sets the entry to password mode.
  *
- * In password mode, entries are implicitly single line and the display of any
- * text in them is replaced with asterisks (*).
+ * In password mode entries are implicitly single line and the display of any
+ * text inside them is replaced with asterisks (*).
  *
+ * @param[in] obj The object.
  * @param[in] password If true, password mode is enabled.
  *
  * @ingroup Efl_Ui_Text
  */
-EOAPI void efl_ui_text_password_set(Eo *obj, Eina_Bool password);
+EOAPI void efl_ui_text_password_mode_set(Eo *obj, Eina_Bool password);
 
 /**
  * @brief Get whether the entry is set to password mode.
  *
+ * @param[in] obj The object.
+ *
  * @return If true, password mode is enabled.
  *
  * @ingroup Efl_Ui_Text
  */
-EOAPI Eina_Bool efl_ui_text_password_get(const Eo *obj);
+EOAPI Eina_Bool efl_ui_text_password_mode_get(const Eo *obj);
 
 /**
  * @brief Set the return key on the input panel to be disabled.
  *
+ * @param[in] obj The object.
  * @param[in] disabled The state to put in in: @c true for disabled, @c false
  * for enabled.
  *
@@ -282,6 +252,8 @@ EOAPI void efl_ui_text_input_panel_return_key_disabled_set(Eo *obj, Eina_Bool di
  * @brief Get whether the return key on the input panel should be disabled or
  * not.
  *
+ * @param[in] obj The object.
+ *
  * @return The state to put in in: @c true for disabled, @c false for enabled.
  *
  * @ingroup Efl_Ui_Text
@@ -289,19 +261,21 @@ EOAPI void efl_ui_text_input_panel_return_key_disabled_set(Eo *obj, Eina_Bool di
 EOAPI Eina_Bool efl_ui_text_input_panel_return_key_disabled_get(const Eo *obj);
 
 /**
- * @brief Set whether the entry should allow to use the text prediction.
+ * @brief Set whether the entry should allow predictive text.
  *
- * @param[in] prediction Whether the entry should allow to use the text
- * prediction.
+ * @param[in] obj The object.
+ * @param[in] prediction Whether the entry should allow predictive text.
  *
  * @ingroup Efl_Ui_Text
  */
 EOAPI void efl_ui_text_prediction_allow_set(Eo *obj, Eina_Bool prediction);
 
 /**
- * @brief Get whether the entry should allow to use the text prediction.
+ * @brief Get whether the entry allows predictive text.
  *
- * @return Whether the entry should allow to use the text prediction.
+ * @param[in] obj The object.
+ *
+ * @return Whether the entry should allow predictive text.
  *
  * @ingroup Efl_Ui_Text
  */
@@ -311,6 +285,7 @@ EOAPI Eina_Bool efl_ui_text_prediction_allow_get(const Eo *obj);
  * @brief Sets the input hint which allows input methods to fine-tune their
  * behavior.
  *
+ * @param[in] obj The object.
  * @param[in] hints Input hint.
  *
  * @ingroup Efl_Ui_Text
@@ -320,6 +295,8 @@ EOAPI void efl_ui_text_input_hint_set(Eo *obj, Elm_Input_Hints hints);
 /**
  * @brief Gets the value of input hint.
  *
+ * @param[in] obj The object.
+ *
  * @return Input hint.
  *
  * @ingroup Efl_Ui_Text
@@ -329,6 +306,7 @@ EOAPI Elm_Input_Hints efl_ui_text_input_hint_get(const Eo *obj);
 /**
  * @brief Set the input panel layout of the entry.
  *
+ * @param[in] obj The object.
  * @param[in] layout Layout type.
  *
  * @ingroup Efl_Ui_Text
@@ -338,6 +316,8 @@ EOAPI void efl_ui_text_input_panel_layout_set(Eo *obj, Elm_Input_Panel_Layout la
 /**
  * @brief Get the input panel layout of the entry.
  *
+ * @param[in] obj The object.
+ *
  * @return Layout type.
  *
  * @ingroup Efl_Ui_Text
@@ -350,6 +330,7 @@ EOAPI Elm_Input_Panel_Layout efl_ui_text_input_panel_layout_get(const Eo *obj);
  *
  * An input panel displays the string or icon associated with this type.
  *
+ * @param[in] obj The object.
  * @param[in] return_key_type The type of "return" key on the input panel.
  *
  * @ingroup Efl_Ui_Text
@@ -359,6 +340,8 @@ EOAPI void efl_ui_text_input_panel_return_key_type_set(Eo *obj, Elm_Input_Panel_
 /**
  * @brief Get the "return" key type.
  *
+ * @param[in] obj The object.
+ *
  * @return The type of "return" key on the input panel.
  *
  * @ingroup Efl_Ui_Text
@@ -368,6 +351,7 @@ EOAPI Elm_Input_Panel_Return_Key_Type efl_ui_text_input_panel_return_key_type_ge
 /**
  * @brief Sets the attribute to show the input panel automatically.
  *
+ * @param[in] obj The object.
  * @param[in] enabled If @c true, the input panel is appeared when entry is
  * clicked or has a focus.
  *
@@ -378,6 +362,8 @@ EOAPI void efl_ui_text_input_panel_enabled_set(Eo *obj, Eina_Bool enabled);
 /**
  * @brief Get the attribute to show the input panel automatically.
  *
+ * @param[in] obj The object.
+ *
  * @return If @c true, the input panel is appeared when entry is clicked or has
  * a focus.
  *
@@ -389,10 +375,11 @@ EOAPI Eina_Bool efl_ui_text_input_panel_enabled_get(const Eo *obj);
  * @brief Set whether the return key on the input panel is disabled
  * automatically when entry has no text.
  *
- * If @c enabled is @c true, The return key on input panel is disabled when the
+ * If @c enabled is @c true, the return key on input panel is disabled when the
  * entry has no text. The return key on the input panel is automatically
  * enabled when the entry has text. The default value is @c false.
  *
+ * @param[in] obj The object.
  * @param[in] enabled If @c enabled is @c true, the return key is automatically
  * disabled when the entry has no text.
  *
@@ -401,24 +388,36 @@ EOAPI Eina_Bool efl_ui_text_input_panel_enabled_get(const Eo *obj);
 EOAPI void efl_ui_text_input_panel_return_key_autoenabled_set(Eo *obj, Eina_Bool enabled);
 
 /**
- * @brief This prepends a custom item provider to the list for that entry
+ * @brief The factory that provides item in the text e.g. "emoticon/happy" or
+ * "href=file://image.jpg" etc.
  *
- * This prepends the given callback.
- *
- * @param[in] func The function called to provide the item object.
- * @param[in] data The data passed to @c func.
+ * @param[in] obj The object.
+ * @param[in] item_factory Factory to create items
  *
  * @ingroup Efl_Ui_Text
  */
-EOAPI void efl_ui_text_item_provider_prepend(Eo *obj, Elm_Entry_Item_Provider_Cb func, void *data);
+EOAPI void efl_ui_text_item_factory_set(Eo *obj, Efl_Canvas_Text_Factory *item_factory);
+
+/**
+ * @brief The factory that provides item in the text e.g. "emoticon/happy" or
+ * "href=file://image.jpg" etc.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Factory to create items
+ *
+ * @ingroup Efl_Ui_Text
+ */
+EOAPI Efl_Canvas_Text_Factory *efl_ui_text_item_factory_get(const Eo *obj);
 
 /**
  * @brief Show the input panel (virtual keyboard) based on the input panel
- * property of entry such as layout, autocapital types, and so on.
+ * property of entry such as layout, autocapital types and so on.
  *
  * Note that input panel is shown or hidden automatically according to the
  * focus state of entry widget. This API can be used in the case of manually
  * controlling by using @ref efl_ui_text_input_panel_enabled_set(en, @c false).
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Ui_Text
  */
@@ -430,24 +429,12 @@ EOAPI void efl_ui_text_input_panel_show(Eo *obj);
  */
 EOAPI void efl_ui_text_selection_copy(Eo *obj);
 
-/**
- * @brief This removes a custom item provider to the list for that entry
- *
- * This removes the given callback. See @ref efl_ui_text_item_provider_append
- * for more information
- *
- * @param[in] func The function called to provide the item object.
- * @param[in] data The data passed to @c func.
- *
- * @ingroup Efl_Ui_Text
- */
-EOAPI void efl_ui_text_item_provider_remove(Eo *obj, Elm_Entry_Item_Provider_Cb func, void *data);
-
 /**
  * @brief This clears and frees the items in a entry's contextual (longpress)
  * menu.
  *
  * See also @ref efl_ui_text_context_menu_item_add.
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Ui_Text
  */
@@ -460,6 +447,7 @@ EOAPI void efl_ui_text_context_menu_clear(Eo *obj);
  * panel. The data format MUST be negotiated by both application and the input
  * panel. The size and format of data are defined by the input panel.
  *
+ * @param[in] obj The object.
  * @param[in] data The specific data to be set to the input panel.
  * @param[in] len The length of data, in bytes, to send to the input panel.
  *
@@ -470,7 +458,8 @@ EOAPI void efl_ui_text_input_panel_imdata_set(Eo *obj, const void *data, int len
 /**
  * @brief Get the specific data of the current input panel.
  *
- * @param[in,out] data The specific data to be got from the input panel.
+ * @param[in] obj The object.
+ * @param[in,out] data The specific data to be obtained from the input panel.
  * @param[out] len The length of data.
  *
  * @ingroup Efl_Ui_Text
@@ -489,6 +478,7 @@ EOAPI void efl_ui_text_selection_paste(Eo *obj);
  * Note that input panel is shown or hidden automatically according to the
  * focus state of entry widget. This API can be used in the case of manually
  * controlling by using @ref efl_ui_text_input_panel_enabled_set(en, @c false)
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Ui_Text
  */
@@ -507,37 +497,19 @@ EOAPI void efl_ui_text_cursor_selection_end(Eo *obj);
  */
 EOAPI void efl_ui_text_selection_cut(Eo *obj);
 
-/**
- * @brief This appends a custom item provider to the list for that entry
- *
- * This appends the given callback. The list is walked from beginning to end
- * with each function called given the item href string in the text. If the
- * function returns an object handle other than @c null (it should create an
- * object to do this), then this object is used to replace that item. If not
- * the next provider is called until one provides an item object, or the
- * default provider in entry does.
- *
- * See also @ref entry-items.
- *
- * @param[in] func The function called to provide the item object.
- * @param[in] data The data passed to @c func.
- *
- * @ingroup Efl_Ui_Text
- */
-EOAPI void efl_ui_text_item_provider_append(Eo *obj, Elm_Entry_Item_Provider_Cb func, void *data);
-
 /**
  * @brief This adds an item to the entry's contextual menu.
  *
- * A longpress on an entry will make the contextual menu show up, if this
- * hasn't been disabled with @ref efl_ui_text_context_menu_disabled_set. By
- * default, this menu provides a few options like enabling selection mode,
- * which is useful on embedded devices that need to be explicit about it, and
- * when a selection exists it also shows the copy and cut actions.
+ * A longpress on an entry will make the contextual menu show up unless this
+ * has been disabled with @ref efl_ui_text_context_menu_disabled_set. By
+ * default this menu provides a few options like enabling selection mode, which
+ * is useful on embedded devices that need to be explicit about it. When a
+ * selection exists it also shows the copy and cut actions.
  *
  * With this function, developers can add other options to this menu to perform
  * any action they deem necessary.
  *
+ * @param[in] obj The object.
  * @param[in] label The item's text label.
  * @param[in] icon_file The item's icon file.
  * @param[in] icon_type The item's icon type.
@@ -551,23 +523,17 @@ EOAPI void efl_ui_text_context_menu_item_add(Eo *obj, const char *label, const c
 /**
  * @brief Creates and returns a new cursor for the text.
  *
+ * @param[in] obj The object.
+ *
  * @return Text cursor
  *
  * @ingroup Efl_Ui_Text
  */
 EOAPI Efl_Text_Cursor_Cursor *efl_ui_text_cursor_new(Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ACTIVATED;
-
-/** Called when entry got activated
- *
- * @ingroup Efl_Ui_Text
- */
-#define EFL_UI_TEXT_EVENT_ACTIVATED (&(_EFL_UI_TEXT_EVENT_ACTIVATED))
-
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CHANGED;
 
-/** Called when entry changed
+/** Called when entry changes
  *
  * @ingroup Efl_Ui_Text
  */
@@ -575,7 +541,8 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CHANGED;
 
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CHANGED_USER;
 
-/** Called when object changed due to user interaction
+/** The text object has changed due to user interaction
+ * @return Efl_Ui_Text_Change_Info
  *
  * @ingroup Efl_Ui_Text
  */
@@ -584,6 +551,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CHANGED_USER;
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_VALIDATE;
 
 /** Called when validating
+ * @return Elm_Validate_Content
  *
  * @ingroup Efl_Ui_Text
  */
@@ -597,30 +565,6 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CONTEXT_OPEN;
  */
 #define EFL_UI_TEXT_EVENT_CONTEXT_OPEN (&(_EFL_UI_TEXT_EVENT_CONTEXT_OPEN))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_CLICKED;
-
-/** Called when anchor was clicked
- *
- * @ingroup Efl_Ui_Text
- */
-#define EFL_UI_TEXT_EVENT_ANCHOR_CLICKED (&(_EFL_UI_TEXT_EVENT_ANCHOR_CLICKED))
-
-EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_REJECTED;
-
-/** Called when entry was rejected
- *
- * @ingroup Efl_Ui_Text
- */
-#define EFL_UI_TEXT_EVENT_REJECTED (&(_EFL_UI_TEXT_EVENT_REJECTED))
-
-EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_MAXLENGTH_REACHED;
-
-/** Called when maximum entry length has been reached
- *
- * @ingroup Efl_Ui_Text
- */
-#define EFL_UI_TEXT_EVENT_MAXLENGTH_REACHED (&(_EFL_UI_TEXT_EVENT_MAXLENGTH_REACHED))
-
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_PREEDIT_CHANGED;
 
 /** Called when entry preedit changed
@@ -639,7 +583,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_PRESS;
 
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_REDO_REQUEST;
 
-/** Called when redo was requested
+/** Called when redo is requested
  *
  * @ingroup Efl_Ui_Text
  */
@@ -647,23 +591,15 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_REDO_REQUEST;
 
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_UNDO_REQUEST;
 
-/** Called when undo was requested
+/** Called when undo is requested
  *
  * @ingroup Efl_Ui_Text
  */
 #define EFL_UI_TEXT_EVENT_UNDO_REQUEST (&(_EFL_UI_TEXT_EVENT_UNDO_REQUEST))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_TEXT_SET_DONE;
-
-/** Called when text set finished
- *
- * @ingroup Efl_Ui_Text
- */
-#define EFL_UI_TEXT_EVENT_TEXT_SET_DONE (&(_EFL_UI_TEXT_EVENT_TEXT_SET_DONE))
-
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ABORTED;
 
-/** Called when entry was aborted
+/** Called when entry is aborted
  *
  * @ingroup Efl_Ui_Text
  */
@@ -672,6 +608,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ABORTED;
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_DOWN;
 
 /** Called on anchor down
+ * @return Elm_Entry_Anchor_Info
  *
  * @ingroup Efl_Ui_Text
  */
@@ -680,6 +617,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_DOWN;
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_HOVER_OPENED;
 
 /** Called when hover opened
+ * @return Elm_Entry_Anchor_Hover_Info
  *
  * @ingroup Efl_Ui_Text
  */
@@ -688,6 +626,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_HOVER_OPENED;
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_IN;
 
 /** Called on anchor in
+ * @return Elm_Entry_Anchor_Info
  *
  * @ingroup Efl_Ui_Text
  */
@@ -696,6 +635,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_IN;
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_OUT;
 
 /** Called on anchor out
+ * @return Elm_Entry_Anchor_Info
  *
  * @ingroup Efl_Ui_Text
  */
@@ -704,19 +644,12 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_OUT;
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ANCHOR_UP;
 
 /** called on anchor up
+ * @return Elm_Entry_Anchor_Info
  *
  * @ingroup Efl_Ui_Text
  */
 #define EFL_UI_TEXT_EVENT_ANCHOR_UP (&(_EFL_UI_TEXT_EVENT_ANCHOR_UP))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CURSOR_CHANGED;
-
-/** Called on cursor changed
- *
- * @ingroup Efl_Ui_Text
- */
-#define EFL_UI_TEXT_EVENT_CURSOR_CHANGED (&(_EFL_UI_TEXT_EVENT_CURSOR_CHANGED))
-
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CURSOR_CHANGED_MANUAL;
 
 /** Called on manual cursor change
@@ -724,5 +657,6 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CURSOR_CHANGED_MANUA
  * @ingroup Efl_Ui_Text
  */
 #define EFL_UI_TEXT_EVENT_CURSOR_CHANGED_MANUAL (&(_EFL_UI_TEXT_EVENT_CURSOR_CHANGED_MANUAL))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
