@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Scene3d;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** A UI view for EFL Canvas 3D.
  *
  * @ingroup Efl_Canvas_Scene3d
@@ -24,10 +25,9 @@ EWAPI const Efl_Class *efl_canvas_scene3d_class_get(void);
 /**
  * @brief The 3d scene to display in this view.
  *
+ * @param[in] obj The object.
  * @param[in] scene 3D scene.
  *
- * @since 1.10
- *
  * @ingroup Efl_Canvas_Scene3d
  */
 EOAPI void efl_canvas_scene3d_set(Eo *obj, Evas_Canvas3D_Scene *scene);
@@ -35,12 +35,13 @@ EOAPI void efl_canvas_scene3d_set(Eo *obj, Evas_Canvas3D_Scene *scene);
 /**
  * @brief The 3d scene to display in this view.
  *
- * @return 3D scene.
+ * @param[in] obj The object.
  *
- * @since 1.10
+ * @return 3D scene.
  *
  * @ingroup Efl_Canvas_Scene3d
  */
 EOAPI Evas_Canvas3D_Scene *efl_canvas_scene3d_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
