@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Surface;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Native surfaces usually bound to an externally-managed buffer.
  *
@@ -24,9 +25,9 @@ typedef Eo Efl_Canvas_Surface;
  *
  * @ingroup Efl_Canvas_Surface
  */
-#define EFL_CANVAS_SURFACE_MIXIN efl_canvas_surface_mixin_get()
+#define EFL_CANVAS_SURFACE_CLASS efl_canvas_surface_class_get()
 
-EWAPI const Efl_Class *efl_canvas_surface_mixin_get(void);
+EWAPI const Efl_Class *efl_canvas_surface_class_get(void);
 
 /**
  * @brief External buffer attached to this native surface.
@@ -57,5 +58,6 @@ EOAPI Eina_Bool efl_canvas_surface_native_buffer_set(Eo *obj, void *buffer) EINA
  * @ingroup Efl_Canvas_Surface
  */
 EOAPI void *efl_canvas_surface_native_buffer_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
