@@ -11,19 +11,19 @@ typedef Eo Efl_Canvas_Surface_X11;
 #ifndef _EFL_CANVAS_SURFACE_X11_EO_TYPES
 #define _EFL_CANVAS_SURFACE_X11_EO_TYPES
 
-/** The type used by @ref Efl.Canvas.Surface.native_buffer.
+#ifdef EFL_BETA_API_SUPPORT
+/** The type used by @ref efl_canvas_surface_native_buffer_get.
  *
- * @ingroup Efl_Canvas_Surface
+ * @ingroup Efl_Canvas
  */
 typedef struct _Efl_Canvas_Surface_X11_Pixmap
 {
   void *visual; /**< X11 Visual for this Pixmap. */
   unsigned long pixmap; /**< X11 Pixmap ID. */
 } Efl_Canvas_Surface_X11_Pixmap;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
 
-
-
 #endif
